==> priority-queue-2.0.0-alpha.0.tgz: package/lib/esm/index.js <==
function createPriorityQueue(cmp) {
    const _tree = [null];
    let _size = 0;
    return {
        init,
        enqueue,
        dequeue,
        top,
        collect,
        size: () => _size,
        isEmpty: () => _size < 1,
    };
    function init(elements) {
        _size = elements == null ? 0 : Math.max(0, elements.length);
        if (_tree.length <= _size)
            _tree.length = _size + 1;
        if (elements == null)
            return;
        for (let i = 0; i < _size; ++i)
            _tree[i + 1] = elements[i];
        for (let q = _size; q > 1; q -= 2)
            _down(q >> 1);
    }
    function enqueue(val) {
        _tree[++_size] = val;
        _up(_size);
    }
    function dequeue() {
        if (_size < 1)
            return undefined;
        const target = _tree[1];
        _tree[1] = _tree[_size--];
        _down(1);
        return target;
    }
    function top() {
        return _size > 0 ? _tree[1] : undefined;
    }
    function collect() {
        return _tree.slice(1);
    }
    function _down(index) {
        for (let p = index; p <= _size;) {
            const lft = p << 1;
            const rht = lft | 1;
            if (lft > _size)
                break;
            const q = rht <= _size && cmp(_tree[rht], _tree[lft]) > 0 ? rht : lft;
            const tmp = _tree[q];
            if (cmp(_tree[p], tmp) >= 0)
                break;
            _tree[q] = _tree[p];
            _tree[p] = tmp;
            p = q;
        }
    }
    function _up(index) {
        for (let i = index; i > 1;) {
            const q = i >> 1;
            const x = _tree[q];
            if (cmp(x, _tree[i]) >= 0)
                break;
            _tree[q] = _tree[i];
            _tree[i] = x;
            i = q;
        }
    }
}

export { createPriorityQueue };

==> priority-queue-2.0.8-alpha.0.tgz: package/lib/esm/index.js <==
function createPriorityQueue(cmp) {
    const _tree = [null];
    let _size = 0;
    return {
        init,
        enqueue,
        dequeue,
        top,
        collect,
        size: () => _size,
        isEmpty: () => _size < 1,
    };
    function init(elements, startIndex, endIndex) {
        if (!elements) {
            _size = 0;
            _tree.length = _size + 1;
            return;
        }
        const sIdx = Math.max(0, Math.min(elements.length, startIndex ?? 0));
        const tIdx = Math.max(sIdx, Math.min(elements.length, endIndex ?? elements.length));
        _size = tIdx - sIdx;
        if (_tree.length <= _size)
            _tree.length = _size + 1;
        for (let i = sIdx, k = 1; i < tIdx; ++i, ++k)
            _tree[k] = elements[i];
        for (let q = _size; q > 1; q -= 2)
            _down(q >> 1);
    }
    function enqueue(val) {
        _tree[++_size] = val;
        _up(_size);
    }
    function dequeue() {
        if (_size < 1)
            return undefined;
        const target = _tree[1];
        _tree[1] = _tree[_size--];
        _down(1);
        return target;
    }
    function top() {
        return _size > 0 ? _tree[1] : undefined;
    }
    function collect() {
        return _tree.slice(1);
    }
    function _down(index) {
        for (let p = index; p <= _size;) {
            const lft = p << 1;
            const rht = lft | 1;
            if (lft > _size)
                break;
            const q = rht <= _size && cmp(_tree[rht], _tree[lft]) > 0 ? rht : lft;
            const tmp = _tree[q];
            if (cmp(_tree[p], tmp) >= 0)
                break;
            _tree[q] = _tree[p];
            _tree[p] = tmp;
            p = q;
        }
    }
    function _up(index) {
        for (let i = index; i > 1;) {
            const q = i >> 1;
            const x = _tree[q];
            if (cmp(x, _tree[i]) >= 0)
                break;
            _tree[q] = _tree[i];
            _tree[i] = x;
            i = q;
        }
    }
}

export { createPriorityQueue };
